@@ -171,6 +171,7 @@ compute_xsettings_dpi (GtkWidget *widget)
     int width, height;
     int dpi;
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     screen = gtk_widget_get_screen (widget);
     width_mm = gdk_screen_get_width_mm (screen);
     height_mm = gdk_screen_get_height_mm (screen);
@@ -183,6 +184,7 @@ compute_xsettings_dpi (GtkWidget *widget)
         dpi = MIN (INCH_MM * width  / width_mm,
                    INCH_MM * height / height_mm);
     }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
     return dpi;
 }
@@ -1218,6 +1220,11 @@ appearance_settings_dialog_configure_widgets (GtkBuilder *builder)
     xfconf_g_property_bind (xsettings_channel,  "/Gtk/FontName", G_TYPE_STRING,
                             G_OBJECT (object), "font-name");
 
+    /* Monospace font name */
+    object = gtk_builder_get_object (builder, "gtk_monospace_fontname_button");
+    xfconf_g_property_bind (xsettings_channel,  "/Gtk/MonospaceFontName", G_TYPE_STRING,
+                            G_OBJECT (object), "font-name");
+
     /* Toolbar style */
     object = gtk_builder_get_object (builder, "gtk_toolbar_style_combo_box");
     appearance_settings_dialog_channel_property_changed (xsettings_channel, "/Gtk/ToolbarStyle", NULL, builder);
@@ -1240,7 +1247,7 @@ appearance_settings_dialog_configure_widgets (GtkBuilder *builder)
     gtk_widget_set_sensitive (GTK_WIDGET (object2), gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (object)));
     g_signal_connect (G_OBJECT (object), "toggled", G_CALLBACK (cb_custom_dpi_check_button_toggled), object2);
     g_signal_connect (G_OBJECT (object2), "value-changed", G_CALLBACK (cb_custom_dpi_spin_button_changed), object);
-    
+
     /* Window scaling factor */
     object = gtk_builder_get_object (builder, "gdk_window_scaling_factor_combo_box");
     appearance_settings_dialog_channel_property_changed (xsettings_channel, "/Gdk/WindowScalingFactor", NULL, builder);
