@@ -249,7 +249,7 @@ xfce_randr_populate (XfceRandr *randr,
 
         /* Update display info, primary display may have changed. */
         xfce_randr_save_output (randr, "Default", display_channel, m);
-        
+
         /* Replace spaces with underscore in name for xfconf compatibility */
         g_strcanon(randr->priv->output_info[m]->name, "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789-_<>", '_');
     }
@@ -549,7 +549,6 @@ xfce_randr_friendly_name (XfceRandr *randr,
 
     /* special case, a laptop */
     if (g_str_has_prefix (name, "LVDS")
-        || g_str_has_prefix (name, "eDP")
         || strcmp (name, "PANEL") == 0)
         return g_strdup (_("Laptop"));
 
@@ -627,6 +626,7 @@ xfce_randr_preferred_mode (XfceRandr *randr,
     best_dist = 0;
     for (n = 0; n < randr->priv->output_info[output]->nmode; ++n)
     {
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         if (n < randr->priv->output_info[output]->npreferred)
             dist = 0;
         else if (randr->priv->output_info[output]->mm_height != 0)
@@ -635,6 +635,7 @@ xfce_randr_preferred_mode (XfceRandr *randr,
                     randr->priv->output_info[output]->mm_height);
         else
             dist = gdk_screen_height () - randr->priv->modes[output][n].height;
+G_GNUC_END_IGNORE_DEPRECATIONS
 
         dist = ABS (dist);
 
